realm.impl.system

Basic implementation of realm.core with the following features:

  • use alternative keywords for add/remove/deps/rename (but only one of each!)
  • validation of component map
  • start/init/etc fn should return a non nil value, which will be stored in the system
  • passes only deps into component's start/init etc, not whole system
  • stop/halt/etc removes key and value from system
  • passes component itself to remove/stop/halt etc, not whole system
  • tap>s when starting or stopping a component by default
  • deps/uses can be a keyword or a collection of keywords
  • use rename/use-as to rename keys in map passed to start/init etc
  • wrap start and stop with try/catch and rethrow with more info
  • updates system var for dev reloaded workflow and/or stopping system on service/job shutdown
  • stop/holt/etc and deps/uses are optional, start/init/etc isn't.
  • throw when start/init/etc function returns a non-nil value
  • start and stop fns are idempotent, meaning, they have no effect when component is already added to or removed from the old context
  • start and stop functions below throw when any component throws when started or stopped by default
  • start and stop functions can be customized by passing in opts to configure realm.core starter and stopper functions.
Basic implementation of realm.core with the following features:
- use alternative keywords for add/remove/deps/rename (but only one of each!)
- validation of component map
- start/init/etc fn should return a non nil value, which will be stored in the system
- passes only deps into component's start/init etc, not whole system
- stop/halt/etc removes key and value from system
- passes component itself to remove/stop/halt etc, not whole system
- tap>s when starting or stopping a component by default
- deps/uses can be a keyword or a collection of keywords
- use rename/use-as to rename keys in map passed to start/init etc
- wrap start and stop with try/catch and rethrow with more info
- updates system var for dev reloaded workflow and/or stopping system on service/job shutdown
- stop/holt/etc and deps/uses are optional, start/init/etc isn't.
- throw when start/init/etc function returns a non-nil value
- start and stop fns are idempotent, meaning, they have no effect when
component is already added to or removed from the old context
- start and stop functions below throw when any component throws when started or stopped by default
- start and stop functions can be customized by passing in opts to configure realm.core starter and stopper functions. 
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries