realm.impl.validate


alternativesclj

source

cmp-kwsclj

(cmp-kws cmp alternatives cmp-kw)

Returns the set of keys in cmp that match the alternative keywords for a logical component keyword group.

Returns the set of keys in cmp that match the alternative keywords for a
logical component keyword group.
sourceraw docstring

rename-cmp-kwclj

(rename-cmp-kw raw-cmp alternatives kw)

Rename kw in cmp map according to alternatives mapping.

Rename kw in cmp map according to alternatives mapping.
sourceraw docstring

rename-cmp-kwsclj

(rename-cmp-kws cmp alternatives)

Rename keys to :start, :stop, :deps and :rename in cmp map according to alternatives mapping.

Rename keys to :start, :stop, :deps and :rename in cmp map according to
alternatives mapping.
sourceraw docstring

validate-cmpclj

(validate-cmp id raw-cmp)

Throw an exception if cmp map is invalid, otherwise just return normalized cmp.

Throw an exception if cmp map is invalid, otherwise just return normalized cmp.
sourceraw docstring

validate-cmpsclj

(validate-cmps cmps)
source

cljdoc builds & hosts documentation for Clojure/Script libraries