(cmp-kws cmp alternatives cmp-kw)Returns the set of keys in cmp that match the alternative keywords for a logical component keyword group.
Returns the set of keys in cmp that match the alternative keywords for a logical component keyword group.
(rename-cmp-kw raw-cmp alternatives kw)Rename kw in cmp map according to alternatives mapping.
Rename kw in cmp map according to alternatives mapping.
(rename-cmp-kws cmp alternatives)Rename keys to :start, :stop, :deps and :rename in cmp map according to alternatives mapping.
Rename keys to :start, :stop, :deps and :rename in cmp map according to alternatives mapping.
(validate-cmp id raw-cmp)Throw an exception if cmp map is invalid, otherwise just return normalized cmp.
Throw an exception if cmp map is invalid, otherwise just return normalized cmp.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |